@@ -7,5 +7,9 @@
 #' @examples today.market()
 #' @export
 today.market=function(){
-  return(gsheet::gsheet2tbl("https://docs.google.com/spreadsheets/d/1WKZphnEyC7RcSbfY_4d3kCRoEskCGY1umKOwMqoaHqM/edit?usp=sharing"))
-}
+  link="https://www.bmcecapitalbourse.com/bkbbourse/lists/TK?q=AE31180F8E3BE20E762758E81EDC1204&t=list&f=1W_PERF_PR&s=true#casapalmares"
+  page=rvest::read_html(link)
+  page=rvest::html_nodes(page,"table")
+  page= rvest::html_table(page)
+  page[[6]]
+  }
